summaryrefslogtreecommitdiff
path: root/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h
diff options
context:
space:
mode:
authorvboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2023-02-01 12:15:57 +0000
committervboxsync <vboxsync@cfe28804-0f27-0410-a406-dd0f0b0b656f>2023-02-01 12:15:57 +0000
commitb240838b5939eb1f5d513f248323bcca62c67c9d (patch)
treef214cfee9bad26a337581b6bcf814acc90c5450c /src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h
parent510a56ee830b617c939ae24d7fd9f06f2fde7c47 (diff)
downloadVirtualBox-svn-b240838b5939eb1f5d513f248323bcca62c67c9d.tar.gz
Merging r155183 and r155198 from gui4 branch: Runtime UI: Provide UIMachineLogic and UIIndicatorsPool with access to UIMachine stuff.
git-svn-id: https://www.virtualbox.org/svn/vbox/trunk@98375 cfe28804-0f27-0410-a406-dd0f0b0b656f
Diffstat (limited to 'src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h')
-rw-r--r--src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h b/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h
index 5d029b2d025..fda36a4e1a7 100644
--- a/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h
+++ b/src/VBox/Frontends/VirtualBox/src/runtime/UIIndicatorsPool.h
@@ -43,6 +43,7 @@
#include "COMEnums.h"
/* Forward declarations: */
+class UIMachine;
class UISession;
class CSession;
class QIStatusBarIndicator;
@@ -65,8 +66,9 @@ signals:
public:
/** Constructor, passes @a pParent to the QWidget constructor.
- * @param pSession is used to retrieve appearance information. */
- UIIndicatorsPool(UISession *pSession, QWidget *pParent = 0);
+ * @param pMachine Brings the machine UI reference.
+ * @param pSession Brings the session UI reference. */
+ UIIndicatorsPool(UIMachine *pMachine, UISession *pSession, QWidget *pParent = 0);
/** Destructor. */
~UIIndicatorsPool();
@@ -120,7 +122,9 @@ private:
/** Updates passed @a pIndicator with current @a state value. */
void updateIndicatorStateForDevice(QIStatusBarIndicator *pIndicator, KDeviceActivity state);
- /** Holds the UI session reference. */
+ /** Holds the machine UI reference. */
+ UIMachine *m_pMachine;
+ /** Holds the session UI reference. */
UISession *m_pSession;
/** Holds whether status-bar is enabled. */
bool m_fEnabled;